@@ -2,7 +2,7 @@
 #include <string.h>
 
 struct some_struct {
-	int some_int;
+	int   some_int;
 	char *some_str;
 };
 
@@ -12,7 +12,12 @@ extern void take_one_struct(struct some_struct *arg) {
 	else
 		printf("not ok - got passed int %d\n", arg -> some_int);
 
-	if (strcmp(arg -> some_str, "hello"))
+	if (strlen(arg -> some_str) == 5)
+		printf("ok - got passed str of right len\n");
+	else
+		printf("not ok - got passed str of len %d\n", strlen(arg -> some_str));
+
+	if (strcmp(arg -> some_str, "hello") == 0)
 		printf("ok - got passed str hello\n");
 	else
 		printf("not ok - got passed str %s\n", arg -> some_str);
